@@ -1,3 +1,5 @@
+from typing import Optional, Union, Dict
+
 from collections import defaultdict
 import os
 import json
@@ -9,6 +11,7 @@ from .lib import mkdir, colorize
 HOME = os.path.expanduser('~')
 CLOUD_VOLUME_DIR = os.path.join(HOME, '.cloudvolume')
 CLOUD_VOLUME_DIR = os.environ.get("CLOUD_VOLUME_DIR", CLOUD_VOLUME_DIR)
+CLOUD_VOLUME_CACHE_DIR = os.environ.get("CLOUD_VOLUME_CACHE_DIR", None)
 
 try:
   mkdir(CLOUD_VOLUME_DIR)
@@ -56,8 +59,11 @@ def default_google_project_name():
 
   return None
 
+CredentialType = Dict[str,Union[str,int]]
+CredentialCacheType = Dict[str,CredentialType]
+
 PROJECT_NAME = default_google_project_name()
-GOOGLE_CREDENTIALS_CACHE = {}
+GOOGLE_CREDENTIALS_CACHE:CredentialCacheType = {}
 google_credentials_path = secretpath('secrets/google-secret.json')
 
 def google_credentials(bucket = ''):
@@ -92,7 +98,7 @@ def google_credentials(bucket = ''):
 
   return project_name, google_credentials
 
-AWS_CREDENTIALS_CACHE = defaultdict(dict)
+AWS_CREDENTIALS_CACHE:CredentialCacheType = defaultdict(dict)
 aws_credentials_path = secretpath('secrets/aws-secret.json')
 def aws_credentials(bucket = '', service = 'aws'):
   global AWS_CREDENTIALS_CACHE
@@ -144,8 +150,8 @@ else:
 
 # Graphene PyChunkGraph server
 # CAVE = Connectomics Annotation Versioning Engine
-CAVE_CREDENTIALS_CACHE = defaultdict(list)
-def cave_credentials(domain=''):
+CAVE_CREDENTIALS_CACHE:CredentialCacheType = defaultdict(dict)
+def cave_credentials(domain=""):
   global CAVE_CREDENTIALS_CACHE
 
   if domain in CAVE_CREDENTIALS_CACHE.keys():
@@ -169,3 +175,28 @@ def cave_credentials(domain=''):
   CAVE_CREDENTIALS_CACHE[domain] = credentials
   return credentials
 
+# This is for (as of this writing anyway) the spatial index
+# when run at huge scale in the cloud.
+MYSQL_CREDENTIALS_CACHE:CredentialCacheType = defaultdict(dict)
+def mysql_credentials(domain=""):
+  global MYSQL_CREDENTIALS_CACHE
+
+  if domain in MYSQL_CREDENTIALS_CACHE.keys():
+    return MYSQL_CREDENTIALS_CACHE[domain]
+
+  default_file_path = secretpath('secrets/mysql-secret.json')
+
+  paths = [ default_file_path ]
+
+  if domain:
+    paths = [ secretpath(f"secrets/{domain}-mysql-secret.json") ] + paths
+
+  credentials = {}
+  for path in paths:
+    if os.path.exists(path):
+      with open(path, 'rt') as f:
+        credentials = json.loads(f.read())
+      break
+
+  MYSQL_CREDENTIALS_CACHE[domain] = credentials
+  return credentials  
